use crate::{
    entity::locale::LocaleType, locales::LocaleTypeExt, markups::language_markup, prelude::*,
};

pub async fn change_locale(
    bot: Throttle<Bot>,
    q: CallbackQuery,
    db: Pool,
    mut locale: LocaleRef,
    new_locale: LocaleType,
) -> crate::Result<()> {
    let mut ids = q.get_ids();
    let user_id = q.from.id.0;

    let is_successful = new_locale
        .update(user_id, &db)
        .await
        .map_err(handle_error)
        .unwrap_or(false);

    if !is_successful {
        ids.alter_message(
            &bot,
            &locale.something_went_wrong,
            deletion_markup(locale),
            None,
        )
        .await?;
        return Ok(());
    }

    locale = new_locale.get_locale();
    ids.alter_message(&bot, &locale.choose_language, language_markup(), None)
        .await?;

    Ok(())
}
