use crate::{change_state, prelude::*};

#[allow(clippy::too_many_arguments)]
async fn get_master_pass(
    bot: Throttle<Bot>,
    msg: Message,
    db: Pool,
    dialogue: MainDialogue,
    mut ids: MessageIds,
    locale: LocaleRef,
    name: String,
    _: String,
) -> crate::Result<()> {
    dialogue.exit().await?;

    let user_id = msg.get_user_id()?;
    Account::delete(user_id, &name, &db).await?;

    ids.alter_message(&bot, &locale.success, deletion_markup(locale), None)
        .await?;

    Ok(())
}

pub async fn delete(
    bot: Throttle<Bot>,
    q: CallbackQuery,
    db: Pool,
    dialogue: MainDialogue,
    locale: LocaleRef,
    (hash, is_command): (super::NameHash, bool),
) -> crate::Result<()> {
    let mut ids = q.get_ids();
    let user_id = q.from.id.0;

    let Some(name) = Account::get_name_by_hash(user_id, &hash, &db).await? else {
        bot.send_message(ids.0, &locale.no_accounts_found)
            .reply_markup(deletion_markup(locale))
            .await?;
        bot.answer_callback_query(q.id).await?;
        return Ok(());
    };

    let text: &str = &locale.send_master_pass_to_delete_account;

    if is_command {
        ids.alter_message(&bot, text, None, None).await?;
    } else {
        let msg = bot.send_message(ids.0, text).await?;
        ids = MessageIds::from(&msg);
    }

    bot.answer_callback_query(q.id).await?;

    change_state!(dialogue, ids, (name), State::GetMasterPass, get_master_pass);

    Ok(())
}
