use crate::{models::User, prelude::*};
use parking_lot::Mutex;
use std::sync::Arc;
use teloxide::types::InputFile;
use tokio::task::spawn_blocking;

/// Decryptes the account on a worker thread and adds it to the accounts vector
async fn decrypt_account(
    account: Account,
    master_pass: Arc<str>,
    accounts: &Mutex<&mut Vec<DecryptedAccount>>,
) -> crate::Result<()> {
    let account =
        spawn_blocking(move || DecryptedAccount::from_account(account, &master_pass)).await??;
    accounts.lock().push(account);
    Ok(())
}

/// Gets the master password, decryptes the account and sends the json file to the user
async fn get_master_pass(
    bot: Throttle<Bot>,
    msg: Message,
    db: Pool,
    dialogue: MainDialogue,
    ids: MessageIds,
    locale: LocaleRef,
    master_pass: String,
) -> crate::Result<()> {
    dialogue.exit().await?;

    ids.delete(&bot).await?;
    let user_id = msg.get_user_id()?;
    let mut accounts = Vec::new();

    {
        let accounts = Mutex::new(&mut accounts);
        let master_pass: Arc<str> = master_pass.into();

        Account::get_all(user_id, &db)
            .err_into::<crate::Error>()
            .try_for_each_concurrent(3, |account| {
                decrypt_account(account, master_pass.clone(), &accounts)
            })
            .await?;
    }

    let json = spawn_blocking(move || {
        accounts.sort_unstable_by(|this, other| this.name.cmp(&other.name));
        serde_json::to_vec_pretty(&User { accounts })
    })
    .await??;
    let file = InputFile::memory(json).file_name("accounts.json");

    bot.send_document(msg.chat.id, file)
        .reply_markup(deletion_markup(locale))
        .await?;
    Ok(())
}

first_handler!(
    export,
    send_master_password,
    State::GetMasterPass,
    get_master_pass
);
