use crate::prelude::*;
use teloxide::{dispatching::DpHandlerDescription, dptree::Handler};

#[allow(clippy::needless_pass_by_value)]
fn has_no_user_info(msg: Message) -> bool {
    msg.from.is_none()
}

async fn notify_about_no_user_info(
    bot: Throttle<Bot>,
    msg: Message,
    state: State,
    locale: LocaleRef,
) -> crate::Result<()> {
    let text = &locale.couldnt_get_user_info_send_again;

    match state {
        State::Start => {
            bot.send_message(msg.chat.id, text)
                .reply_markup(deletion_markup(locale))
                .await?;
        }
        State::GetNewName(handler)
        | State::GetMasterPass(handler)
        | State::GetNewMasterPass(handler)
        | State::GetLogin(handler)
        | State::GetPassword(handler) => {
            handler
                .lock()
                .await
                .previous
                .alter_message(&bot, text, None, None)
                .await?;
        }
        State::GetUser(handler) => {
            handler
                .lock()
                .await
                .previous
                .alter_message(&bot, text, None, None)
                .await?;
        }
    }

    Ok(())
}

/// Gets a handler that filters out the messages without user information
pub fn get_handler() -> Handler<'static, DependencyMap, crate::Result<()>, DpHandlerDescription> {
    dptree::filter(has_no_user_info).endpoint(notify_about_no_user_info)
}
