mod callbacks;
mod commands;
mod cryptography;
mod dispatching;
mod entity;
mod errors;
mod locales;
mod macros;
mod markups;
mod models;
mod prelude;
mod state;
mod utils;

use anyhow::{Error, Result};

#[tokio::main]
async fn main() -> Result<()> {
    use std::env;

    let _ = dotenvy::dotenv();
    errors::init_logger();

    locales::LocaleStore::init();

    let token = env::var("TOKEN").expect("expected TOKEN in the enviroment");
    let database_url = env::var("DATABASE_URL").expect("expected DATABASE_URL in the enviroment");
    let pool = entity::Pool::connect(&database_url).await?;

    entity::migrate(&pool).await?;

    Box::pin(dispatching::get_dispatcher(token, pool).dispatch()).await;
    Ok(())
}
